@@ -34,6 +34,7 @@
 #include <telepathy-glib/account-manager.h>
 #include <telepathy-glib/util.h>
 
+#include <libempathy/empathy-client-factory.h>
 #include <libempathy/empathy-tp-contact-factory.h>
 #include <libempathy/empathy-contact-list.h>
 #include <libempathy/empathy-contact-groups.h>
@@ -48,7 +49,6 @@
 #include "empathy-cell-renderer-activatable.h"
 #include "empathy-ui-utils.h"
 #include "empathy-gtk-enum-types.h"
-#include "empathy-gtk-marshal.h"
 
 #define DEBUG_FLAG EMPATHY_DEBUG_CONTACT
 #include <libempathy/empathy-debug.h>
@@ -331,20 +331,6 @@ contact_list_view_drag_got_contact (TpConnection            *connection,
 
 	list = empathy_contact_list_store_get_list_iface (priv->store);
 
-	if (!tp_strdiff (data->new_group, EMPATHY_CONTACT_LIST_STORE_FAVORITE)) {
-		/* Mark contact as favourite */
-		empathy_contact_list_add_to_favourites (list, contact);
-		return;
-	}
-
-	if (!tp_strdiff (data->old_group, EMPATHY_CONTACT_LIST_STORE_FAVORITE)) {
-		/* Remove contact as favourite */
-		empathy_contact_list_remove_from_favourites (list, contact);
-		/* Don't try to remove it */
-		g_free (data->old_group);
-		data->old_group = NULL;
-	}
-
 	if (data->new_group) {
 		empathy_contact_list_add_to_group (list, contact, data->new_group);
 	}
@@ -353,27 +339,6 @@ contact_list_view_drag_got_contact (TpConnection            *connection,
 	}
 }
 
-static gboolean
-group_can_be_modified (const gchar *name,
-		       gboolean     is_fake_group,
-		       gboolean     adding)
-{
-	/* Real groups can always be modified */
-	if (!is_fake_group)
-		return TRUE;
-
-	/* The favorite fake group can be modified so users can
-	 * add/remove favorites using DnD */
-	if (!tp_strdiff (name, EMPATHY_CONTACT_LIST_STORE_FAVORITE))
-		return TRUE;
-
-	/* We can remove contacts from the 'ungrouped' fake group */
-	if (!adding && !tp_strdiff (name, EMPATHY_CONTACT_LIST_STORE_UNGROUPED))
-		return TRUE;
-
-	return FALSE;
-}
-
 static gboolean
 contact_list_view_contact_drag_received (GtkWidget         *view,
 					 GdkDragContext    *context,
@@ -382,7 +347,7 @@ contact_list_view_contact_drag_received (GtkWidget         *view,
 					 GtkSelectionData  *selection)
 {
 	EmpathyContactListViewPriv *priv;
-	TpAccountManager           *account_manager;
+	EmpathyClientFactory       *factory;
 	TpConnection               *connection = NULL;
 	TpAccount                  *account = NULL;
 	DndGetContactData          *data;
@@ -401,9 +366,6 @@ contact_list_view_contact_drag_received (GtkWidget         *view,
 	new_group = empathy_contact_list_store_get_parent_group (model,
 								 path, NULL, &new_group_is_fake);
 
-	if (!group_can_be_modified (new_group, new_group_is_fake, TRUE))
-		return FALSE;
-
 	/* Get source group information. */
 	if (priv->drag_row) {
 		source_path = gtk_tree_row_reference_get_path (priv->drag_row);
@@ -414,21 +376,20 @@ contact_list_view_contact_drag_received (GtkWidget         *view,
 		}
 	}
 
-	if (!group_can_be_modified (old_group, old_group_is_fake, FALSE))
-		return FALSE;
-
 	if (!tp_strdiff (old_group, new_group)) {
 		g_free (new_group);
 		g_free (old_group);
 		return FALSE;
 	}
 
-	account_manager = tp_account_manager_dup ();
+	factory = empathy_client_factory_dup ();
 	strv = g_strsplit (sel_data, ":", 2);
 	if (g_strv_length (strv) == 2) {
 		account_id = strv[0];
 		contact_id = strv[1];
-		account = tp_account_manager_ensure_account (account_manager, account_id);
+		account = tp_simple_client_factory_ensure_account (
+				TP_SIMPLE_CLIENT_FACTORY (factory),
+				account_id, NULL, NULL);
 	}
 	if (account) {
 		connection = tp_account_get_connection (account);
@@ -438,7 +399,7 @@ contact_list_view_contact_drag_received (GtkWidget         *view,
 		DEBUG ("Failed to get connection for account '%s'", account_id);
 		g_free (new_group);
 		g_free (old_group);
-		g_object_unref (account_manager);
+		g_object_unref (factory);
 		return FALSE;
 	}
 
@@ -454,7 +415,7 @@ contact_list_view_contact_drag_received (GtkWidget         *view,
 						data, (GDestroyNotify) contact_list_view_dnd_get_contact_free,
 						G_OBJECT (view));
 	g_strfreev (strv);
-	g_object_unref (account_manager);
+	g_object_unref (factory);
 
 	return TRUE;
 }
@@ -1034,15 +995,6 @@ contact_list_view_group_icon_cell_data_func (GtkTreeViewColumn     *tree_column,
 	if (!is_group)
 		goto out;
 
-	if (!tp_strdiff (name, EMPATHY_CONTACT_LIST_STORE_FAVORITE)) {
-		pixbuf = empathy_pixbuf_from_icon_name ("emblem-favorite",
-			GTK_ICON_SIZE_MENU);
-	}
-	else if (!tp_strdiff (name, EMPATHY_CONTACT_LIST_STORE_PEOPLE_NEARBY)) {
-		pixbuf = empathy_pixbuf_from_icon_name ("im-local-xmpp",
-			GTK_ICON_SIZE_MENU);
-	}
-
 out:
 	g_object_set (cell,
 		      "visible", pixbuf != NULL,
@@ -1781,7 +1733,7 @@ empathy_contact_list_view_class_init (EmpathyContactListViewClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      0,
 			      NULL, NULL,
-			      _empathy_gtk_marshal_VOID__OBJECT_STRING_STRING,
+			      g_cclosure_marshal_generic,
 			      G_TYPE_NONE,
 			      3, EMPATHY_TYPE_CONTACT, G_TYPE_STRING, G_TYPE_STRING);
 
@@ -2051,7 +2003,6 @@ static void
 contact_list_view_remove_activate_cb (GtkMenuItem            *menuitem,
 				      EmpathyContactListView *view)
 {
-	EmpathyContactListViewPriv *priv = GET_PRIV (view);
 	EmpathyContact             *contact;
 
 	contact = empathy_contact_list_view_dup_selected (view);
@@ -2064,10 +2015,7 @@ contact_list_view_remove_activate_cb (GtkMenuItem            *menuitem,
 		text = g_strdup_printf (_("Do you really want to remove the contact '%s'?"),
 					empathy_contact_get_alias (contact));
 		if (contact_list_view_remove_dialog_show (parent, _("Removing contact"), text)) {
-			EmpathyContactList *list;
-
-			list = empathy_contact_list_store_get_list_iface (priv->store);
-			empathy_contact_list_remove (list, contact, "");
+			empathy_contact_remove_from_contact_list (contact);
 		}
 
 		g_free (text);
