@@ -280,7 +280,7 @@ individual_view_drag_motion_cb (GtkWidget *widget,
 
   target = gtk_drag_dest_find_target (GTK_WIDGET (view), context, NULL);
 
-  if (target == gdk_atom_intern_static_string ("text/persona-id"))
+  if (target == gdk_atom_intern_static_string ("text/x-persona-id"))
     {
       GtkTreePath *path;
 
@@ -355,17 +355,18 @@ set_up (EmpathyIndividualLinker *self)
 
   priv = GET_PRIV (self);
 
-  top_vbox = gtk_vbox_new (FALSE, 6);
+  top_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
 
   /* Layout panes */
-  paned = GTK_PANED (gtk_hpaned_new ());
+
+  paned = GTK_PANED (gtk_paned_new (GTK_ORIENTATION_HORIZONTAL));
 
   /* Left column heading */
   alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
   gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 0, 6);
   gtk_widget_show (alignment);
 
-  vbox = GTK_BOX (gtk_vbox_new (FALSE, 6));
+  vbox = GTK_BOX (gtk_box_new (GTK_ORIENTATION_VERTICAL, 6));
   label = gtk_label_new (NULL);
   tmp = g_strdup_printf ("<b>%s</b>", _("Select contacts to link"));
   gtk_label_set_markup (GTK_LABEL (label), tmp);
@@ -439,7 +440,7 @@ set_up (EmpathyIndividualLinker *self)
   gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 6, 0);
   gtk_widget_show (alignment);
 
-  vbox = GTK_BOX (gtk_vbox_new (FALSE, 6));
+  vbox = GTK_BOX (gtk_box_new (GTK_ORIENTATION_VERTICAL, 6));
   label = gtk_label_new (NULL);
   tmp = g_strdup_printf ("<b>%s</b>", _("New contact preview"));
   gtk_label_set_markup (GTK_LABEL (label), tmp);
@@ -572,7 +573,7 @@ finalize (GObject *object)
 {
   EmpathyIndividualLinkerPriv *priv = GET_PRIV (object);
 
-  g_hash_table_destroy (priv->changed_individuals);
+  g_hash_table_unref (priv->changed_individuals);
 
   G_OBJECT_CLASS (empathy_individual_linker_parent_class)->finalize (object);
 }
