@@ -119,6 +119,10 @@ gboolean empathy_individual_view_get_show_untrusted (
 void empathy_individual_view_set_show_untrusted (EmpathyIndividualView *self,
     gboolean show_untrusted);
 
+void empathy_individual_view_set_show_uninteresting (
+    EmpathyIndividualView *view,
+    gboolean show_uninteresting);
+
 gboolean empathy_individual_view_is_searching (
     EmpathyIndividualView *view);
 
