@@ -35,10 +35,12 @@
 #include <telepathy-glib/util.h>
 
 #include <gst/farsight/fs-element-added-notifier.h>
+#include <gst/farsight/fs-utils.h>
 
 #include <libempathy/empathy-tp-contact-factory.h>
 #include <libempathy/empathy-utils.h>
 #include <libempathy-gtk/empathy-avatar-image.h>
+#include <libempathy-gtk/empathy-dialpad-widget.h>
 #include <libempathy-gtk/empathy-ui-utils.h>
 #include <libempathy-gtk/empathy-sound-manager.h>
 #include <libempathy-gtk/empathy-geometry.h>
@@ -336,26 +338,24 @@ empathy_streamed_media_window_setup_toolbar (EmpathyStreamedMediaWindow *self)
 }
 
 static void
-dtmf_button_pressed_cb (GtkButton *button, EmpathyStreamedMediaWindow *window)
+dtmf_start_tone_cb (EmpathyDialpadWidget *dialpad,
+    TpDTMFEvent event,
+    EmpathyStreamedMediaWindow *window)
 {
   EmpathyStreamedMediaWindowPriv *priv = GET_PRIV (window);
   EmpathyTpStreamedMedia *call;
-  GQuark button_quark;
-  TpDTMFEvent event;
 
   g_object_get (priv->handler, "tp-call", &call, NULL);
 
-  button_quark = g_quark_from_static_string (EMPATHY_DTMF_BUTTON_ID);
-  event = GPOINTER_TO_UINT (g_object_get_qdata (G_OBJECT (button),
-    button_quark));
-
   empathy_tp_streamed_media_start_tone (call, event);
 
   g_object_unref (call);
 }
 
 static void
-dtmf_button_released_cb (GtkButton *button, EmpathyStreamedMediaWindow *window)
+dtmf_stop_tone_cb (EmpathyDialpadWidget *self,
+    TpDTMFEvent event,
+    EmpathyStreamedMediaWindow *window)
 {
   EmpathyStreamedMediaWindowPriv *priv = GET_PRIV (window);
   EmpathyTpStreamedMedia *call;
@@ -371,7 +371,7 @@ static GtkWidget *
 empathy_streamed_media_window_create_video_input_add_slider (EmpathyStreamedMediaWindow *self,
   gchar *label_text, GtkWidget *bin)
 {
-   GtkWidget *vbox = gtk_vbox_new (FALSE, 2);
+   GtkWidget *vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 2);
    GtkWidget *scale = gtk_vscale_new_with_range (0, 100, 10);
    GtkWidget *label = gtk_label_new (label_text);
 
@@ -426,7 +426,8 @@ empathy_streamed_media_window_create_video_input (EmpathyStreamedMediaWindow *se
   EmpathyStreamedMediaWindowPriv *priv = GET_PRIV (self);
   GtkWidget *hbox;
 
-  hbox = gtk_hbox_new (TRUE, 3);
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 3);
+  gtk_box_set_homogeneous (GTK_BOX (hbox), TRUE);
 
   priv->video_contrast = empathy_streamed_media_window_create_video_input_add_slider (
     self,  _("Contrast"), hbox);
@@ -533,9 +534,10 @@ empathy_streamed_media_window_create_audio_input (EmpathyStreamedMediaWindow *se
   EmpathyStreamedMediaWindowPriv *priv = GET_PRIV (self);
   GtkWidget *hbox, *vbox, *label;
 
-  hbox = gtk_hbox_new (TRUE, 3);
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 3);
+  gtk_box_set_homogeneous (GTK_BOX (hbox), TRUE);
 
-  vbox = gtk_vbox_new (FALSE, 3);
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 3);
   gtk_box_pack_start (GTK_BOX (hbox), vbox, FALSE, FALSE, 3);
 
   priv->volume_scale = gtk_vscale_new_with_range (0, 150, 100);
@@ -982,8 +984,6 @@ empathy_streamed_media_window_init (EmpathyStreamedMediaWindow *self)
   GtkWidget *arrow;
   GtkWidget *page;
   gchar *filename;
-  GKeyFile *keyfile;
-  GError *error = NULL;
   GtkWidget *scroll;
 
   filename = empathy_file_lookup ("empathy-streamed-media-window.ui", "src");
@@ -1037,7 +1037,8 @@ empathy_streamed_media_window_init (EmpathyStreamedMediaWindow *self)
 
   gtk_container_add (GTK_CONTAINER (self), top_vbox);
 
-  priv->content_hbox = gtk_hbox_new (FALSE, CONTENT_HBOX_SPACING);
+  priv->content_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL,
+      CONTENT_HBOX_SPACING);
   gtk_container_set_border_width (GTK_CONTAINER (priv->content_hbox),
                                   CONTENT_HBOX_BORDER_WIDTH);
   gtk_paned_pack1 (GTK_PANED (priv->pane), priv->content_hbox, TRUE, FALSE);
@@ -1050,7 +1051,7 @@ empathy_streamed_media_window_init (EmpathyStreamedMediaWindow *self)
       priv->remote_user_output_frame, TRUE, TRUE,
       CONTENT_HBOX_CHILDREN_PACKING_PADDING);
 
-  priv->remote_user_output_hbox = gtk_hbox_new (FALSE, 0);
+  priv->remote_user_output_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 
   priv->remote_user_avatar_widget = gtk_image_new ();
 
@@ -1065,7 +1066,7 @@ empathy_streamed_media_window_init (EmpathyStreamedMediaWindow *self)
   gtk_widget_set_size_request (priv->self_user_output_frame,
       SELF_VIDEO_SECTION_WIDTH, SELF_VIDEO_SECTION_HEIGTH);
 
-  priv->self_user_output_hbox = gtk_hbox_new (FALSE, 0);
+  priv->self_user_output_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 
   priv->self_user_avatar_widget = gtk_image_new ();
   gtk_box_pack_start (GTK_BOX (priv->self_user_output_hbox),
@@ -1085,22 +1086,7 @@ empathy_streamed_media_window_init (EmpathyStreamedMediaWindow *self)
   /* The call will be started as soon the pipeline is playing */
   priv->start_call_when_playing = TRUE;
 
-  keyfile = g_key_file_new ();
-  filename = empathy_file_lookup ("element-properties", "data");
-  if (g_key_file_load_from_file (keyfile, filename, G_KEY_FILE_NONE, &error))
-    {
-      fs_element_added_notifier_set_properties_from_keyfile (priv->fsnotifier,
-          keyfile);
-    }
-  else
-    {
-      g_warning ("Could not load element-properties file: %s", error->message);
-      g_key_file_free (keyfile);
-      g_clear_error (&error);
-    }
-  g_free (filename);
-
-  priv->vbox = gtk_vbox_new (FALSE, 3);
+  priv->vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 3);
   gtk_box_pack_start (GTK_BOX (priv->content_hbox), priv->vbox,
       FALSE, FALSE, CONTENT_HBOX_CHILDREN_PACKING_PADDING);
   gtk_box_pack_start (GTK_BOX (priv->vbox), priv->self_user_output_frame,
@@ -1115,7 +1101,7 @@ empathy_streamed_media_window_init (EmpathyStreamedMediaWindow *self)
 
   gtk_button_set_image (GTK_BUTTON (priv->sidebar_button), arrow);
 
-  h = gtk_hbox_new (FALSE, 3);
+  h = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 3);
   gtk_box_pack_end (GTK_BOX (priv->vbox), h, FALSE, FALSE, 3);
   gtk_box_pack_end (GTK_BOX (h), priv->sidebar_button, FALSE, FALSE, 3);
 
@@ -1134,9 +1120,11 @@ empathy_streamed_media_window_init (EmpathyStreamedMediaWindow *self)
   ev_sidebar_add_page (EV_SIDEBAR (priv->sidebar), "video-input",
       _("Video input"), page);
 
-  priv->dtmf_panel = empathy_create_dtmf_dialpad (G_OBJECT (self),
-      G_CALLBACK (dtmf_button_pressed_cb),
-      G_CALLBACK (dtmf_button_released_cb));
+  priv->dtmf_panel = empathy_dialpad_widget_new ();
+  g_signal_connect (priv->dtmf_panel, "start-tone",
+      G_CALLBACK (dtmf_start_tone_cb), self);
+  g_signal_connect (priv->dtmf_panel, "stop-tone",
+      G_CALLBACK (dtmf_stop_tone_cb), self);
   ev_sidebar_add_page (EV_SIDEBAR (priv->sidebar), "dialpad",
       _("Dialpad"), priv->dtmf_panel);
 
@@ -1758,6 +1746,12 @@ empathy_streamed_media_window_conference_added_cb (EmpathyStreamedMediaHandler *
 {
   EmpathyStreamedMediaWindow *self = EMPATHY_STREAMED_MEDIA_WINDOW (user_data);
   EmpathyStreamedMediaWindowPriv *priv = GET_PRIV (self);
+  GKeyFile *keyfile;
+
+  keyfile = fs_utils_get_default_element_properties (conference);
+  if (keyfile != NULL)
+    fs_element_added_notifier_set_properties_from_keyfile (priv->fsnotifier,
+        keyfile);
 
   gst_bin_add (GST_BIN (priv->pipeline), conference);
 
@@ -1841,16 +1835,16 @@ reset_details_pane (EmpathyStreamedMediaWindow *self)
 
   /* translators: encoding video codec is unknown */
   gtk_label_set_text (GTK_LABEL (priv->vcodec_encoding_label),
-      C_("encoding video codec", "Unknown"));
+      C_("codec", "Unknown"));
   /* translators: encoding audio codec is unknown */
   gtk_label_set_text (GTK_LABEL (priv->acodec_encoding_label),
-      C_("encoding audio codec", "Unknown"));
+      C_("codec", "Unknown"));
   /* translators: decoding video codec is unknown */
   gtk_label_set_text (GTK_LABEL (priv->vcodec_decoding_label),
-      C_("decoding video codec", "Unknown"));
+      C_("codec", "Unknown"));
   /* translators: decoding audio codec is unknown */
   gtk_label_set_text (GTK_LABEL (priv->acodec_decoding_label),
-      C_("decoding audio codec", "Unknown"));
+      C_("codec", "Unknown"));
 }
 
 static gboolean
@@ -2176,7 +2170,7 @@ display_error (EmpathyStreamedMediaWindow *self,
   content_area = gtk_info_bar_get_content_area (GTK_INFO_BAR (info_bar));
 
   /* hbox containing the image and the messages vbox */
-  hbox = gtk_hbox_new (FALSE, 3);
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 3);
   gtk_container_add (GTK_CONTAINER (content_area), hbox);
 
   /* Add image */
@@ -2184,7 +2178,7 @@ display_error (EmpathyStreamedMediaWindow *self,
   gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
 
   /* vbox containing the main message and the details expander */
-  vbox = gtk_vbox_new (FALSE, 3);
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 3);
   gtk_box_pack_start (GTK_BOX (hbox), vbox, TRUE, TRUE, 0);
 
   /* Add text */
